@@ -18,7 +18,7 @@ def xmind_to_zentao_csv_file(xmind_file):
     logging.info('Start converting XMind file(%s) to zentao file...', xmind_file)
     testcases = get_xmind_testcase_list(xmind_file)
 
-    fileheader = ["所属模块", "用例标题", "前置条件", "步骤", "预期", "关键词", "优先级", "用例类型", "适用阶段"]
+    fileheader = ["所属模块", "用例标题", "前置条件", "步骤", "预期", "关键词", "优先级", "用例类型", "适用阶段", "相关研发需求"]
     zentao_testcase_rows = [fileheader]
     for testcase in testcases:
         row = gen_a_testcase_row(testcase)
@@ -30,7 +30,7 @@ def xmind_to_zentao_csv_file(xmind_file):
         # logging.info('The zentao csv file already exists, return it directly: %s', zentao_file)
         # return zentao_file
 
-    with open(zentao_file, 'w', encoding='gbk') as f:
+    with open(zentao_file, 'w', encoding='gbk', errors='ignore') as f:
         writer = csv.writer(f)
         writer.writerows(zentao_testcase_rows)
         logging.info('Convert XMind file(%s) to a zentao csv file(%s) successfully!', xmind_file, zentao_file)
@@ -48,7 +48,9 @@ def gen_a_testcase_row(testcase_dict):
     case_type = gen_case_type(testcase_dict['execution_type'])
     # case_apply_phase = '迭代测试'
     case_apply_phase = gen_case_apply_phase(testcase_dict['summary'])
-    row = [case_module, case_title, case_precontion, case_step, case_expected_result, case_keyword, case_priority, case_type, case_apply_phase]
+    # case_rp_bind = gen_case_apply_phase(testcase_dict[''])
+    case_rp_bind = ''
+    row = [case_module, case_title, case_precontion, case_step, case_expected_result, case_keyword, case_priority, case_type, case_apply_phase, case_rp_bind]
     return row
 
 
